==> use-query-display-0.0.2-alpha.1.tgz: package/es/index.js <==
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 能力
 * 1. 请求链路上：`参数管理` --> `发起请求` --> `请求完成` --> `页面渲染`
 * 2. 合并插件能力 (middlewares & props)
 * 3. 暴露哪些 props
 */
import { useMemo, useRef } from 'react';
import createPluginManager from './plugin';
import composer, { pipeMergedCompose, onionCompose, timelineCompose } from './compose';
import checker, { isFunction } from './checker';
import { PAYLOAD_SYMBOL, REQUEST_SYMBOL } from './symbol';
export * from './type';
export { PAYLOAD_SYMBOL, REQUEST_SYMBOL };

var useInit = function useInit(fn) {
  var ref = useRef(true);

  if (ref.current) {
    ref.current = false;
    fn();
  }
}; // 请求中间件化


var createQuery = function createQuery(ctx, plugins) {
  return function (payload) {
    var meta = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    ctx[PAYLOAD_SYMBOL] = payload;
    ctx.meta = meta;
    return onionCompose(timelineCompose(ctx[REQUEST_SYMBOL].timelines, plugins.middlewares || []))(ctx);
  };
};

var usePlugin = function usePlugin(pluginContext) {
  var plugin = useMemo(createPluginManager, []);
  useInit(function () {
    plugin.context.set(pluginContext);
  });
  plugin.pureUse(pluginContext.rawPlugins);
  var plugins = useMemo(plugin.get, []); // 只有第一个 props 优先级最高，因为它是 Native plugin props

  var pluginsProps = plugins.props.slice(0, 1).concat(plugins.props.slice(1).map(function (p) {
    return isFunction(p) ? p(pluginContext.app.ctx) : p;
  }));
  var props = pipeMergedCompose(pluginsProps);
  pluginContext.plugins = plugins;
  pluginContext.props = props;
  return pluginContext;
};

var useQueryDisplay = function useQueryDisplay(request, rawPlugins) {
  var app = useMemo(function () {
    return {
      query: function query() {
        return Promise.resolve();
      },
      ctx: _defineProperty({}, REQUEST_SYMBOL, request),
      helper: _objectSpread(_objectSpread({}, checker), composer)
    };
  }, []);

  var _usePlugin = usePlugin({
    rawPlugins: rawPlugins,
    app: app
  }),
      props = _usePlugin.props,
      plugins = _usePlugin.plugins;

  var query = useMemo(function () {
    return createQuery(app.ctx, plugins);
  }, [plugins, request]);
  app.query = query;
  return {
    props: props,
    plugins: plugins,
    query: query
  };
};

export default useQueryDisplay;

==> use-query-display-0.0.3-alpha.1.tgz: package/es/index.js <==
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 能力
 * 1. 请求链路上：`参数管理` --> `发起请求` --> `请求完成` --> `页面渲染`
 * 2. 合并插件能力 (middlewares & props)
 * 3. 暴露哪些 props
 */
import { useMemo, useRef } from 'react';
import createPluginManager from './plugin';
import composer, { pipeMergedCompose, onionCompose, timelineCompose } from './compose';
import checker, { isFunction } from './checker';
import { PAYLOAD_SYMBOL, REQUEST_SYMBOL } from './symbol';
import { IS_NATIVE_SYMBOL } from './symbol';
export * from './type';
export * from './checker';
export { PAYLOAD_SYMBOL, REQUEST_SYMBOL };

var useInit = function useInit(fn) {
  var ref = useRef(true);

  if (ref.current) {
    ref.current = false;
    fn();
  }
}; // 请求中间件化


var createQuery = function createQuery(ctx, plugins) {
  return function (payload) {
    var meta = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    ctx[PAYLOAD_SYMBOL] = payload;
    ctx.meta = meta;
    return onionCompose(timelineCompose(ctx[REQUEST_SYMBOL].timelines, plugins.middlewares || []))(ctx);
  };
};

var usePlugin = function usePlugin(pluginManagerContext) {
  var pluginManager = useMemo(createPluginManager, []);
  useInit(function () {
    pluginManager.context.set(pluginManagerContext);
  }); // 每次执行都重新计算插件

  pluginManager.pureUse(pluginManagerContext.rawPlugins);
  var plugins = useMemo(pluginManager.get, []);
  var pluginsProps = plugins.props.filter(function (prop) {
    return prop[IS_NATIVE_SYMBOL];
  }).reverse().concat(plugins.props.reduce(function (acc, prop) {
    if (prop[IS_NATIVE_SYMBOL]) {
      return acc;
    } else {
      return acc.concat(isFunction(prop) ? prop(pluginManagerContext.app.ctx) : prop);
    }
  }, []));
  var props = pipeMergedCompose(pluginsProps);
  pluginManagerContext.plugins = plugins;
  pluginManagerContext.props = props;
  return pluginManagerContext;
};

var useQueryDisplay = function useQueryDisplay(request, rawPlugins) {
  var app = useMemo(function () {
    return {
      query: function query() {
        return Promise.resolve();
      },
      ctx: _defineProperty({}, REQUEST_SYMBOL, request),
      helper: _objectSpread(_objectSpread({}, checker), composer)
    };
  }, []);

  var _usePlugin = usePlugin({
    rawPlugins: rawPlugins,
    app: app
  }),
      props = _usePlugin.props,
      plugins = _usePlugin.plugins;

  var query = useMemo(function () {
    return createQuery(app.ctx, plugins);
  }, [plugins, request]);
  app.query = query;
  return {
    props: props,
    plugins: plugins,
    query: query
  };
};

export default useQueryDisplay;
